Fix DDR6 errata on TQM834x boards
Patch by Thomas Waehner, 7 Mar 2006

Signed-off-by: Martin Krause <martin.krause@tqs.de>

---
commit 815cc23eec28efa1c72eccddf79fb02bea0d5622
tree 273d57034afe87da51a24f947893ceb0e2fa38cd
parent 9c575e51dec11f304bfdc8bcc3aada7af79823b1
author Martin Krause <mkr@tq-sewsrv-4.tq-net.de> Thu, 09 Mar 2006 11:06:24 +0100
committer Martin Krause <mkr@tq-sewsrv-4.tq-net.de> Thu, 09 Mar 2006 11:06:24 +0100

 board/tqm834x/tqm834x.c |   24 ++++++++++++++++++++++++
 1 files changed, 24 insertions(+), 0 deletions(-)

diff --git a/board/tqm834x/tqm834x.c b/board/tqm834x/tqm834x.c
index dada673..b9fd5bd 100644
--- a/board/tqm834x/tqm834x.c
+++ b/board/tqm834x/tqm834x.c
@@ -405,4 +405,28 @@ static void set_ddr_config(void) {
 		(DDR_REFINT_166MHZ_7US << SDRAM_INTERVAL_REFINT_SHIFT) |
 		(DDR_BSTOPRE << SDRAM_INTERVAL_BSTOPRE_SHIFT);
 	SYNC;
+
+	/* Workaround for DDR6 Erratum
+	 * see MPC8349E Device Errata Rev.8, 2/2006
+	 * This workaround influences the MPC internal "input enables"
+	 * dependent on CAS latency and MPC revision. According to errata
+	 * sheet the internal reserved registers for this workaround are
+	 * not available from revision 2.0 and up.
+	 */
+
+	/* Get REVID from register SPRIDR. Skip workaround if rev >= 2.0
+	 * (0x200)
+	 */
+	if ((im->sysconf.spridr & SPRIDR_REVID) < 0x200) {
+
+		/* There is a internal reserved register at IMMRBAR+0x2F00
+		 * which has to be written with a certain value defined by
+		 * errata sheet.
+		 */
+#if defined(DDR_CASLAT_20)
+		*((u8 *)im + 0x2f00) = 0x201c0000;
+#else
+		*((u8 *)im + 0x2f00) = 0x202c0000;
+#endif
+	}
 }
